/*******************************************************************************
Chapter 16

Figure 16.5  A specification of the belief network of rhe sensor network in
Fig. 16.1 modified to have states yes and no.

Belief network is represented by relations:
    parent( ParentNode, Node)
    p( Node, ParentStates, Prob)
        where Prob is conditional probability of Node given
        values of parent variables ParentStates, for example:
        p( alarm, [ burglary, not lighting], 0.99)
    p( Node, Prob) probability of node without parents

Query: prob(alarm=yes, [], P)
       prob(alarm=yes, [burglary=yes], P)
       prob(burglary=yes, [alarm=yes], P)
       prob(burglary=yes, [alarm=yes, call=yes], P)
       prob([lightning=yes, burglary=no], [alarm=yes], P).
*******************************************************************************/

:- [bayesianNet_multistate].

parent(burglary, sensor).    % Burglary tends to trigger sensor
parent(lightning, sensor).   % Strong lightning may trigger sensor
parent(sensor, alarm).
parent(sensor, call).

p(burglary=yes, 0.001).
p(burglary=no, 0.999).

p(lightning=yes, 0.02).
p(lightning=no, 0.98).

p(sensor=yes, [burglary=yes, lightning=yes], 0.9).
p(sensor=yes, [burglary=yes, lightning=no],  0.9).
p(sensor=yes, [burglary=no,  lightning=yes], 0.1).
p(sensor=yes, [burglary=no,  lightning=no],  0.001).

p(sensor=no, [burglary=yes, lightning=yes], 0.1).
p(sensor=no, [burglary=yes, lightning=no],  0.1).
p(sensor=no, [burglary=no,  lightning=yes], 0.9).
p(sensor=no, [burglary=no,  lightning=no],  0.999).

p(alarm=yes, [sensor=yes], 0.95).
p(alarm=yes, [sensor=no],  0.001).

p(alarm=no, [sensor=yes], 0.05).
p(alarm=no, [sensor=no],  0.999).

p(call=yes, [sensor=yes], 0.9).
p(call=yes, [sensor=no],  0.0).

p(call=no, [sensor=yes], 0.1).
p(call=no, [sensor=no],  1.0).
