/*******************************************************************************
Childrens party food choices

Example model from AgenaRisk Lite.

You are organizing a birthday party for N children.  You have hamburgers,
hot dogs and pizza slices on the menu.  The problem is to determine how many of
each to buy.  The first step is to determine what fraction of each product
a child will eat.  We assume the following.
- Each child will eat 2 items
- If the first item is a hamburger (50%) then the second item may be a slice of
  pizza (60%), another hamburger (30%), or a hotdog (10%).
- If the first item is a slice of pizza (30%) then the second item may be
  another slice of pizza (60%), a hot dog (20%), or a hamburger (20%).
- If the first item is a hot dog (20%) the second item may be another
  hot dog (80%), a slice of pizza (10%) or a hamburger (10%).

Call:  displayStats(N) where N is the number of children
                       N must be instantiated

Query: percentProb(hamPerChild=0,[],Pham0)
       prob(hamPerChild=0,[],Pham0)

*******************************************************************************/

:- [bayesianNet_multistate].

parent(first, hamPerChild).
parent(first, pizPerChild).
parent(first, hotPerChild).
parent(first, second).

parent(second, hamPerChild).
parent(second, pizPerChild).
parent(second, hotPerChild).

p(first=hamburger, 0.50).
p(first=pizza, 0.30).
p(first=hotdog, 0.20).

p(second=hamburger, [first=hamburger], 0.30).
p(second=pizza,     [first=hamburger], 0.60).
p(second=hotdog,    [first=hamburger], 0.10).

p(second=hamburger, [first=pizza], 0.20).
p(second=pizza,     [first=pizza], 0.60).
p(second=hotdog,    [first=pizza], 0.20).

p(second=hamburger, [first=hotdog], 0.10).
p(second=pizza,     [first=hotdog], 0.10).
p(second=hotdog,    [first=hotdog], 0.80).

p(hamPerChild=0, [first=hamburger, second=hamburger], 0.0).
p(hamPerChild=1, [first=hamburger, second=hamburger], 0.0).
p(hamPerChild=2, [first=hamburger, second=hamburger], 1.0).
p(hamPerChild=0, [first=hamburger, second=pizza],     0.0).
p(hamPerChild=1, [first=hamburger, second=pizza],     1.0).
p(hamPerChild=2, [first=hamburger, second=pizza],     0.0).
p(hamPerChild=0, [first=hamburger, second=hotdog],    0.0).
p(hamPerChild=1, [first=hamburger, second=hotdog],    1.0).
p(hamPerChild=2, [first=hamburger, second=hotdog],    0.0).

p(hamPerChild=0, [first=pizza, second=hamburger], 0.0).
p(hamPerChild=1, [first=pizza, second=hamburger], 1.0).
p(hamPerChild=2, [first=pizza, second=hamburger], 0.0).
p(hamPerChild=0, [first=pizza, second=pizza],     1.0).
p(hamPerChild=1, [first=pizza, second=pizza],     0.0).
p(hamPerChild=2, [first=pizza, second=pizza],     0.0).
p(hamPerChild=0, [first=pizza, second=hotdog],    1.0).
p(hamPerChild=1, [first=pizza, second=hotdog],    0.0).
p(hamPerChild=2, [first=pizza, second=hotdog],    0.0).

p(hamPerChild=0, [first=hotdog, second=hamburger], 0.0).
p(hamPerChild=1, [first=hotdog, second=hamburger], 1.0).
p(hamPerChild=2, [first=hotdog, second=hamburger], 0.0).
p(hamPerChild=0, [first=hotdog, second=pizza],     1.0).
p(hamPerChild=1, [first=hotdog, second=pizza],     0.0).
p(hamPerChild=2, [first=hotdog, second=pizza],     0.0).
p(hamPerChild=0, [first=hotdog, second=hotdog],    1.0).
p(hamPerChild=1, [first=hotdog, second=hotdog],    0.0).
p(hamPerChild=2, [first=hotdog, second=hotdog],    0.0).
%%%%%%%%%%%%%%%%%%%%
p(pizPerChild=0, [first=hamburger, second=hamburger], 1.0).
p(pizPerChild=1, [first=hamburger, second=hamburger], 0.0).
p(pizPerChild=2, [first=hamburger, second=hamburger], 0.0).
p(pizPerChild=0, [first=hamburger, second=pizza],     0.0).
p(pizPerChild=1, [first=hamburger, second=pizza],     1.0).
p(pizPerChild=2, [first=hamburger, second=pizza],     0.0).
p(pizPerChild=0, [first=hamburger, second=hotdog],    1.0).
p(pizPerChild=1, [first=hamburger, second=hotdog],    0.0).
p(pizPerChild=2, [first=hamburger, second=hotdog],    0.0).

p(pizPerChild=0, [first=pizza, second=hamburger], 0.0).
p(pizPerChild=1, [first=pizza, second=hamburger], 1.0).
p(pizPerChild=2, [first=pizza, second=hamburger], 0.0).
p(pizPerChild=0, [first=pizza, second=pizza],     0.0).
p(pizPerChild=1, [first=pizza, second=pizza],     0.0).
p(pizPerChild=2, [first=pizza, second=pizza],     1.0).
p(pizPerChild=0, [first=pizza, second=hotdog],    0.0).
p(pizPerChild=1, [first=pizza, second=hotdog],    1.0).
p(pizPerChild=2, [first=pizza, second=hotdog],    0.0).

p(pizPerChild=0, [first=hotdog, second=hamburger], 1.0).
p(pizPerChild=1, [first=hotdog, second=hamburger], 0.0).
p(pizPerChild=2, [first=hotdog, second=hamburger], 0.0).
p(pizPerChild=0, [first=hotdog, second=pizza],     0.0).
p(pizPerChild=1, [first=hotdog, second=pizza],     1.0).
p(pizPerChild=2, [first=hotdog, second=pizza],     0.0).
p(pizPerChild=0, [first=hotdog, second=hotdog],    1.0).
p(pizPerChild=1, [first=hotdog, second=hotdog],    0.0).
p(pizPerChild=2, [first=hotdog, second=hotdog],    0.0).
%%%%%%%%%%%%%%%%%%%%
p(hotPerChild=0, [first=hamburger, second=hamburger], 1.0).
p(hotPerChild=1, [first=hamburger, second=hamburger], 0.0).
p(hotPerChild=2, [first=hamburger, second=hamburger], 0.0).
p(hotPerChild=0, [first=hamburger, second=pizza],     1.0).
p(hotPerChild=1, [first=hamburger, second=pizza],     0.0).
p(hotPerChild=2, [first=hamburger, second=pizza],     0.0).
p(hotPerChild=0, [first=hamburger, second=hotdog],    0.0).
p(hotPerChild=1, [first=hamburger, second=hotdog],    1.0).
p(hotPerChild=2, [first=hamburger, second=hotdog],    0.0).

p(hotPerChild=0, [first=pizza, second=hamburger], 1.0).
p(hotPerChild=1, [first=pizza, second=hamburger], 0.0).
p(hotPerChild=2, [first=pizza, second=hamburger], 0.0).
p(hotPerChild=0, [first=pizza, second=pizza],     1.0).
p(hotPerChild=1, [first=pizza, second=pizza],     0.0).
p(hotPerChild=2, [first=pizza, second=pizza],     0.0).
p(hotPerChild=0, [first=pizza, second=hotdog],    0.0).
p(hotPerChild=1, [first=pizza, second=hotdog],    1.0).
p(hotPerChild=2, [first=pizza, second=hotdog],    0.0).

p(hotPerChild=0, [first=hotdog, second=hamburger], 0.0).
p(hotPerChild=1, [first=hotdog, second=hamburger], 1.0).
p(hotPerChild=2, [first=hotdog, second=hamburger], 0.0).
p(hotPerChild=0, [first=hotdog, second=pizza],     0.0).
p(hotPerChild=1, [first=hotdog, second=pizza],     1.0).
p(hotPerChild=2, [first=hotdog, second=pizza],     0.0).
p(hotPerChild=0, [first=hotdog, second=hotdog],    0.0).
p(hotPerChild=1, [first=hotdog, second=hotdog],    0.0).
p(hotPerChild=2, [first=hotdog, second=hotdog],    1.0).

/*******************************************************************************
Produce the relevant statistical tables
*******************************************************************************/

displayStats(N) :-
  percentProb(hamPerChild=0,[],Pham0),
  percentProb(hamPerChild=1,[],Pham1),
  percentProb(hamPerChild=2,[],Pham2),
  percentProb(pizPerChild=0,[],Ppiz0),
  percentProb(pizPerChild=1,[],Ppiz1),
  percentProb(pizPerChild=2,[],Ppiz2),
  percentProb(hotPerChild=0,[],Phot0),
  percentProb(hotPerChild=1,[],Phot1),
  percentProb(hotPerChild=2,[],Phot2),
  displayTable(Pham0, Pham1, Pham2, Ppiz0, Ppiz1, Ppiz2, Phot0, Phot1, Phot2),
  NumHam is round(N*(Pham1 + 2*Pham2)/100),
  NumPiz is round(N*(Ppiz1 + 2*Ppiz2)/100),
  NumHot is round(N*(Phot1 + 2*Phot2)/100),
  displayCounts(NumHam, NumPiz, NumHot).

displayTable(Pham0, Pham1, Pham2, Ppiz0, Ppiz1, Ppiz2, Phot0, Phot1, Phot2) :-
  write('   Hamburgers  Pizza  Hot Dogs'), nl,
  write('0       '), write(Pham0), write('%     '), write(Ppiz0),
      write('%     '), write(Phot0), write('%'), nl,
  write('1       '), write(Pham1), write('%     '), write(Ppiz1),
      write('%     '), write(Phot1), write('%'), nl,
  write('2       '), write(Pham2), write('%     '), write(Ppiz2),
      write('%     '), write(Phot2), write('%'), nl, nl.

displayCounts(NumHam, NumPiz, NumHot) :-
  write('Number of food items\n'),
  write('   Hamburgers  Pizza  Hot Dogs'), nl,
  write('         '), write(NumHam), write('      '), write(NumPiz),
  write('      '), write(NumHot), nl, nl.


