/*******************************************************************************
Harvard Medical Problem

One in a thousand people has a prevalence for a particular heart disease.
There is a test to detect this disease.  The test is 100% accurate for people
who have the disease and is 95% accurate for those who don't have the disease
(this means that 5% of people who do not have the disease will be wrongly
diagnosed as having it). If a randomly selectd person tests positive what is
the probability that the person actually has the disease?

Probablity is < 2%.  In a test at Harvard University, most doctors and medical
students said 95% with an 'average' answer of 56%.
-- Base Rate Neglect is the basis fo the fallacy for the wrong answer; i.e.
they did not take into account the base rate of 1/1000 has the disease.

Risk Assessment & Decision Analysis with Bayesian Networks,
Norman Fenton & Martin Neil.
p27, p118..121 & p262
********************************************************************************
Belief network is represented by relations:
    parent( ParentNode, Node)
    p( Node, ParentStates, Prob)
        where Prob is conditional probability of Node given
        values of parent variables ParentStates, for example:
        p( alarm, [ burglary, not earthquake], 0.99)
    p( Node, Prob) probability of node without parents

Query: prob(disease, [test], P).
*******************************************************************************/

:- ['f16_4_BayesianNet.pl'].

parent(disease, test).

p(disease, 0.001).          % Prob of disease with no evidence

p(test, [ disease], 1.00).  % Prob of positive test if disease is present
                            % 1.0 means no false negatives. 
p(test, [~disease], 0.05).  % Prob of positive test if disease is not present
                            % False positive
