/*******************************************************************************
Norman and Martin late for work

Norman takes the train to work.  If the train is delayed then Norman may be late.
Martin takes the train to work.  If the train is delayed then Martin may be late.
Martin may oversleep and may be late as a result.

Risk Assessment & Decision Analysis with Bayesian Networks,
Norman Fenton & Martin Neil.
p134
********************************************************************************
Belief network is represented by relations:
    parent( ParentNode, Node)
    p( Node, ParentStates, Prob)
        where Prob is conditional probability of Node given
        values of parent variables ParentStates, for example:
        p( alarm, [ burglary, not earthquake], 0.99)
    p( Node, Prob) probability of node without parents

Query:  prob(normanLate, [],P)
        prob(normanLate, [martinLate], P)
        prob(normanLate, [martinLate, martinOversleeps], P))
        prob(normanLate, [martinOversleeps], P))
*******************************************************************************/

:- ['f16_4_BayesianNet.pl'].

parent(trainDelayed, normanLate).
parent(trainDelayed, martinLate).
parent(martinOversleeps, martinLate).

p(trainDelayed, 0.1).       % Prob train will be delayed
p(martinOversleeps, 0.4).   % Prob Martin oversleeps

p(normanLate, [trainDelayed], 0.8).     % Prob Norman late if train delayed
p(normanLate, [~trainDelayed], 0.1).    % Prob Norman late if train not delayed

    % Martin late has two parents so a probability is given of all combinations
    % of parent conditions need to be given.

p(martinLate, [martinOversleeps, trainDelayed], 0.8).
p(martinLate, [martinOversleeps, ~trainDelayed], 0.6).
p(martinLate, [~martinOversleeps, trainDelayed], 0.6).
p(martinLate, [~martinOversleeps, ~trainDelayed], 0.3).
