/*******************************************************************************
Prosecutor Fallacy

The chances that an innocent person has the matching blood type is 1/1000.
Fred, a random person from a town with 10,000 people, has the matching blood type.
Therefore the chances that Fred is innocent is just 1/1000 (0.1%) or guilty with
probability of 999/1000 (99.9%).

Actually, there are 10 people with matching blood type. So there is only a 9%
chance that Fred was at the scene (guility) and a 91% chance that he is innocent.

On the flip side is the Defendant's fallacy as follows.
  The evidence presented by the prosecution leads us to conclude that there
  is actually a very high probability that the defendant is innocent.  Therefore
  this evidence is worthless even for the prosecutor's argument and so can safely
  be ignored.
The argument is wrong because the evidence has moved our belief in Fred being
at the scene from 1/10,000 to about 9/100.  A significant change that cannot be
ignored.

Risk Assessment & Decision Analysis with Bayesian Networks,
Norman Fenton & Martin Neil.
p28 & 124
********************************************************************************
Belief network is represented by relations:
    parent( ParentNode, Node)
    p( Node, ParentStates, Prob)
        where Prob is conditional probability of Node given
        values of parent variables ParentStates, for example:
        p( alarm, [ burglary, not earthquake], 0.99)
    p( Node, Prob) probability of node without parents

Query: prob(atCrimeScene, [bloodMatch], P).
*******************************************************************************/

:- ['f16_4_BayesianNet.pl'].

parent(atCrimeScene, bloodMatch).

p(atCrimeScene, 0.0001).                % Fred one of 10,000 potential
                                        % people that could be picked up.

p(bloodMatch, [atCrimeScene], 1.0).     % If Fred at scene, then his blood
p(bloodMatch, [~atCrimeScene], 0.001).  % If Fred not at scene,
                                        % then 1/1000 prob match
